aboutsummaryrefslogtreecommitdiffhomepage
path: root/Eigen/src/Core/Random.h
diff options
context:
space:
mode:
authorGravatar Benoit Jacob <jacob.benoit.1@gmail.com>2008-02-28 12:38:12 +0000
committerGravatar Benoit Jacob <jacob.benoit.1@gmail.com>2008-02-28 12:38:12 +0000
commit6907886a156c4b94ec7530351b271e1c1bc5b81b (patch)
tree9c9431ba83e0234e5f199031ed48915ad6365422 /Eigen/src/Core/Random.h
parentc67e717404258d3625a74c67f50be34939af6d95 (diff)
prefix global functions with ei_ as previous solution was rather
fragile. also fix compilation with g++ 4.3.
Diffstat (limited to 'Eigen/src/Core/Random.h')
-rw-r--r--Eigen/src/Core/Random.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/Eigen/src/Core/Random.h b/Eigen/src/Core/Random.h
index 89febe4f3..793e45505 100644
--- a/Eigen/src/Core/Random.h
+++ b/Eigen/src/Core/Random.h
@@ -55,7 +55,7 @@ template<typename MatrixType> class Random : NoOperatorEquals,
Scalar _coeff(int, int) const
{
- return Eigen::random<Scalar>();
+ return ei_random<Scalar>();
}
public:
@@ -78,13 +78,13 @@ template<typename MatrixType> class Random : NoOperatorEquals,
* the returned matrix. Must be compatible with this MatrixBase type.
*
* This variant is meant to be used for dynamic-size matrix types. For fixed-size types,
* it is redundant to pass \a rows and \a cols as arguments, so random() should be used
* instead.
*
* Example: \include MatrixBase_random_int_int.cpp
* Output: \verbinclude MatrixBase_random_int_int.out
*
- * \sa random(), random(int)
+ * \sa ei_random(), ei_random(int)
*/
template<typename Scalar, typename Derived>
const Eval<Random<Derived> >
@@ -101,13 +101,13 @@ MatrixBase<Scalar, Derived>::random(int rows, int cols)
* \only_for_vectors
*
* This variant is meant to be used for dynamic-size vector types. For fixed-size types,
* it is redundant to pass \a size as argument, so random() should be used
* instead.
*
* Example: \include MatrixBase_random_int.cpp
* Output: \verbinclude MatrixBase_random_int.out
*
- * \sa random(), random(int,int)
+ * \sa ei_random(), ei_random(int,int)
*/
template<typename Scalar, typename Derived>
const Eval<Random<Derived> >
@@ -127,7 +127,7 @@ MatrixBase<Scalar, Derived>::random(int size)
* Example: \include MatrixBase_random.cpp
* Output: \verbinclude MatrixBase_random.out
*
- * \sa random(int), random(int,int)
+ * \sa ei_random(int), ei_random(int,int)
*/
template<typename Scalar, typename Derived>
const Eval<Random<Derived> >
@@ -141,7 +141,7 @@ MatrixBase<Scalar, Derived>::random()
* Example: \include MatrixBase_setRandom.cpp
* Output: \verbinclude MatrixBase_setRandom.out
*
- * \sa class Random, random()
+ * \sa class Random, ei_random()
*/
template<typename Scalar, typename Derived>
Derived& MatrixBase<Scalar, Derived>::setRandom()
@@ -78,13 +78,13 @@ template<typename MatrixType> class Random : NoOperatorEquals,
*
* This variant is meant to be used for dynamic-size matrix types. For fixed-size types,
- * it is redundant to pass \a rows and \a cols as arguments, so random() should be used
+ * it is redundant to pass \a rows and \a cols as arguments, so ei_random() should be used
* instead.
*
@@ -101,13 +101,13 @@ MatrixBase<Scalar, Derived>::random(int rows, int cols)
*
* This variant is meant to be used for dynamic-size vector types. For fixed-size types,
- * it is redundant to pass \a size as argument, so random() should be used
+ * it is redundant to pass \a size as argument, so ei_random() should be used
* instead.
*